@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1998/07/14 09:32:15 $
-# $Revision: 1.18.1.86 $
+# $Date: 1998/07/14 15:42:16 $
+# $Revision: 1.18.1.87 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -17,6 +17,7 @@ proc InitClasses {} {
 class Channel {
     timestamp	0	{bool {Display Timestamps}}
     noshare	0	{bool {Do Not Share}}
+    nomerge	0	{bool {Do Not Merge}}
     monitor	0	{bool}
     menu	0	{bool {Add to Channel Menu}}
     join	0	{bool {Join at Startup}}
@@ -177,6 +178,8 @@ class Window {
     children	{}
     timed	1
     iconop	{iconify}
+    cols	1
+    curcol	0
 }
 #
 class User {} {
