@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Look.tcl,v $
-# $Date: 1998/07/09 14:44:08 $
-# $Revision: 1.18.1.20 $
+# $Date: 1998/07/14 15:42:25 $
+# $Revision: 1.18.1.21 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -71,14 +71,18 @@ proc merge {args} {
     global Share currentNet
     set args [getType $args t]
     set Share([newName Share]) \
-      [list $currentNet $t [string tolower [lindex $args 0]] [getNet [lindex $args 1]] 1]
+      [list $currentNet $t [string tolower [lindex $args 0]] [getNet [lindex $args 1]] 1 1]
 }
 #
 proc share {args} {
     global Share currentNet
     set args [getType $args t]
+    set cols 1
+    if {[regexp {^\*([0-9]+)$} [lindex $args 0] m cols]} {
+        set args [lrange $args 1 end]
+    }
     set Share([newName Share]) \
-      [list $currentNet $t [string tolower [lindex $args 0]] [getNet [lindex $args 1]] 0]
+      [list $currentNet $t [string tolower [lindex $args 0]] [getNet [lindex $args 1]] 0 $cols]
 }
 #
 proc InitLook {} {
@@ -88,26 +92,26 @@ proc InitLook {} {
 	        {Popper {Info {limit create url topic}} {Flags {key mod log}}}
 	        {Popper {Control {Mode Info Action Users Quit Clear}}}
 	        {Text Users}
-	        Entry
+	        {{Entry scroll}}
 	    }
     look -channel {^\\&.*$} {.*} {
 	        {Popper {Info {limit create url topic}} {Flags {key mod log}}}
 	        {Popper {Control {Mode Info Action Users Quit Clear}}}
 	        {Text {Users off}}
-	        Entry
+	        {{Entry scroll}}
 	    }
     look -channel {.*} {.*} [list \
 		[list [list Popper] [list Topic]] \
 	        [list [list Popper] [list Info [list limit create url topic]] [list Flags [list key mod log]]] \
 	        [list [list Popper] [list Control [list Mode Info Action Users Quit Clear]]] \
 	        [list [list Text] [list Users]] \
-	        [list [list Entry]] \
+	        [list [list Entry scroll]] \
 	    ]
-    look -message -chat -notice -- {.*} {.*} {
-		{Popper {Control {Mode Info Action Users Quit Clear}}}
-		{Text {Users off}}
-		Entry
-	}
+    look -message -chat -notice -- {.*} {.*} [list \
+		[list [list Popper] [list Control [list Mode Info Action Users Quit Clear]]] \
+		[list [list Text] [list Users off]]\
+		[list [list Entry scroll]]\
+	]
     array set DLook [array get Look]
     unset Look
 }
@@ -140,18 +144,15 @@ proc findStyle {id name net} {
     set style original
     if {![$id noshare]} {
 	foreach x [array names Share] {
-	    set type [lindex $Share($x) 1]
-	    set cptn [lindex $Share($x) 2]
-	    set nptn [lindex $Share($x) 3]
+	    foreach {nt type cptn nptn mrg col} $Share($x) break
 	    if {[regexp -nocase $type [$id type]] &&
-	      [regexp -nocase $cptn $name] && [regexp -nocase $nptn $net]} {
-	        if {[lindex $Share($x) 4]} { set style hicaffiene } {set style diet}
-	        return [list $style .$x]
-	        break
+	      [regexp -nocase $cptn $name] && [regexp -nocase $nptn [$net name]]} {
+	        if {$mrg} { set style hicaffiene } {set style diet}
+	        return [list $style .$x $col]
 	    }
 	}
     }
-    return [list $style .$id]
+    return [list $style .$id 1]
 }
 #
 proc cnvType {desc ty} {
@@ -163,19 +164,17 @@ proc saveLook {desc net} {
     global Look
     set cm 1
     foreach x [lsort [array names Look]] {
-	switch -- [lindex $Look($x) 0] $net {
-	    set type [lindex $Look($x) 1]
-	    set cptn [lindex $Look($x) 2]
-	    set nptn [lindex $Look($x) 3]
+        foreach {nt type cptn nptn val} $Look($x) break
+	switch -- $nt $net {
 	    if {$cm} { puts $desc "#\n# Layout control\n#" ; set cm 0 }
 	    puts -nonewline $desc look
 	    cnvType $desc $type
 	    if {[string match -* $cptn]} { puts -nonewline $desc -- }
-	    puts -nonewline $desc " {$cptn}"
+	    puts -nonewline $desc " [list $cptn]"
 	    switch -- [subst $nptn] [$net name] {} default {
-		puts -nonewline " $nptn"
+		puts -nonewline " [list $nptn]"
 	    }
-	    puts $desc " [lindex $x 4]"
+	    puts $desc " $val"
 	}
     }
 
@@ -185,18 +184,17 @@ proc saveShare {desc net} {
     global Share
     set cm 1
     foreach x [lsort [array names Share]] {
-	switch -- [lindex $Share($x) 0] $net {
-	    set type [lindex $Share($x) 1]
-	    set cptn [lindex $Share($x) 2]
-	    set nptn [lindex $Share($x) 3]
-	    if {[lindex $Share($x) 4]} { set pc merge } { set pc share }
+        foreach {nt type cptn nptn mrg cols} $Share($x) break
+	switch -- $nt $net {
+	    if {$mrg} { set pc merge } { set pc share }
 	    if {$cm} { puts $desc "#\n# Window Sharing\n#" ; set cm 0 }
 	    puts -nonewline $desc $pc
 	    cnvType $desc $type
 	    if {[string match -* $cptn]} { puts -nonewline $desc -- }
-	    puts -nonewline $desc " {$cptn}"
+	    if {!$mrg && $cols > 1} { puts -nonewline $desc " *$cols" }
+	    puts -nonewline $desc " [list $cptn]"
 	    switch [subst $nptn] [$net name] {} default {
-		puts -nonewline $desc " $nptn"
+		puts -nonewline $desc " [list $nptn]"
 	    }
 	    puts $desc {}
 	}
