@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/07/10 11:05:13 $
-# $Revision: 1.18.1.148 $
+# $Date: 1998/07/14 09:32:19 $
+# $Revision: 1.18.1.150 $
 #
 package provide zircon 1.18
 #
@@ -282,7 +282,7 @@ proc net_startIRC {this srv args} {
     $this show
     set server [$srv host]
     $this configure -ircop 0 -msgQueue {} -msgQTag {} -sysQueue {} \
-      -hostid $srv -motdSeen 0 closing {}
+      -hostid $srv -motdSeen 0 closing {} -whohandler {}
     set ctl [$this control]
     set ost [$ctl openState]
     set ports [$srv selport]
@@ -653,6 +653,10 @@ proc net_ircTests {this} {
 proc net_isonTest {this} {
     upvar #0 $this ndata
     $this ISON
+    foreach gf  [$this globfriend] {
+        $this sysQ "WHO :$gf"
+	lappend ndata(whohandler) globfon
+    }
     if {$ndata(notifyInterval)} {after $ndata(notifyInterval) "$this isonTest"}
 }
 #
@@ -751,6 +755,12 @@ proc net_MODE {this who mode args} {
     }
 }
 #
+proc net_WHO {this chans} {
+    upvar #0 $this ndata
+    lappend ndata(whohandler) doWhoLine
+    $this q1Send "WHO [colonLast $chans]"
+}
+#
 proc net_CONNECT {this srv port remote} {
     switch {} $srv return
     $this q1Send "CONNECT $srv $port :$remote"
