@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
-# $Date: 1998/07/14 09:32:22 $
-# $Revision: 1.18.1.71 $
+# $Date: 1998/07/15 13:39:32 $
+# $Revision: 1.18.1.73 $
 #
 package provide zircon 1.18
 #
@@ -280,13 +280,17 @@ proc rebind {txt net} {
 #
 proc retitle {t w1 w2} { wm title $w2 $t }
 #
-proc switchFrame {ctl net title args} {
+proc switchFrame {ctl net title col args} {
     global zDIOff
     set rq [llength [grid slaves $ctl -column 0]]
-    grid rowconfigure $ctl $rq -weight 1 -minsize 30
-    grid columnconfigure $ctl 0 -weight 1
+    if {$col > 0} {
+        incr rq -1
+    } {
+        grid rowconfigure $ctl $rq -weight 1 -minsize 30
+    }
+    grid columnconfigure $ctl $col -weight 1
     grid [set mn [frame $ctl.$net -borderwidth 0]] -sticky nsew \
-      -row $rq -column 0
+      -row $rq -column $col
 #    switch {} $args {} default {
 #	update idletasks
 #	set h [frame $mn.h$net -bg blue -borderwidth 4]
@@ -377,11 +381,69 @@ proc hideFrame {ctl net} {
 }
 #
 proc deleteFrame {ctl net} {
-     array set ginf [grid info $ctl.$net]
-     destroy $ctl.$net
-     grid rowconfigure $ctl $ginf(-row) -weight 0 -minsize 0
+    array set ginf [grid info $ctl.$net]
+    destroy $ctl.$net
+    minRow $ctl $ginf(-row)
+#    shuffleFrame $ctl
 }
 #
+proc shuffleFrame {ctl} {
+    foreach {cols rows} [grid size $ctl] break
+    foreach w [grid slaves $ctl] {
+        array set ginf [grid info $w]
+	set occ($ginf(-row),$ginf(-column)) $w
+    }
+    set mvd 1
+    set rws [expr {$rows -1}]
+    while {$mvd} {
+        set mvd 0
+        for {set c 0} {$c < $cols} {incr c} {
+	    for {set r 0} {$r < $rws} {incr r} {
+	        set r1 [expr {$r + 1}]
+	        if {![info exists occ($r,$c)] && [info exists occ($r1,$c)]} {
+		    moveFrame $occ($r1,$c) $r $c
+		    set occ($r,$c) $occ($r1,$c)
+		    unset occ($r1,$c)
+		    set mvd 1
+		}
+	    }
+	}
+    }
+    set mvd 1
+    set cls [expr {$cols -1}]
+    while {$mvd} {
+        set mvd 0
+        for {set r 0} {$r < $rows} {incr r} {
+	    for {set c 0} {$c < $cls} {incr c} {
+	        set c1 [expr {$c + 1}]
+	        if {![info exists occ($r,$c)] && [info exists occ($r,$c1)]} {
+		    moveFrame $occ($r,$c1) $r $c
+		    set occ($r,$c) $occ($r,$c1)
+		    unset occ($r,$c1)
+		    set mvd 1
+		}
+	    }
+	}
+    }
+}
+#
+proc minRow {ctl row} {
+     foreach x [grid slaves $ctl] {
+         array set sinf [grid info $x]
+	 if {$sinf(-row) == $row} return
+     }
+     grid rowconfigure $ctl $row -weight 0 -minsize 0
+}
+#
+proc moveFrame {w row col} {
+     array set ginf [grid info $w]
+     grid remove $w
+     minRow [winfo parent $w] $ginf(-row)
+     set ginf(-row) $row
+     set ginf(-column) $col
+     eval grid $w [array get ginf] 
+}
+
 proc makeMB {win text} {
     menubutton $win -text [trans $text] -menu $win.menu -padx 4 -pady 5
     return [menu $win.menu]
