@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Window.tcl,v $
-# $Date: 1998/07/10 13:33:56 $
-# $Revision: 1.18.1.36 $
+# $Date: 1998/07/14 15:42:29 $
+# $Revision: 1.18.1.37 $
 #
 package provide zircon 1.18
 #
@@ -162,6 +162,15 @@ proc window_configure {this args} {
     }
 }
 #
+proc window_nextCol {this} {
+    upvar #0 $this wdata
+    set cl $wdata(curcol)
+    if {[incr wdata(curcol)] >= $wdata(cols)} {
+        set wdata(curcol) 0
+    }
+    return $cl
+}
+#
 proc window_register {this id lcmd dcmd} {
     upvar #0 $this wdata
     lappend wdata(children) [list $id $lcmd $dcmd]
